pub struct Ctrl(/* private fields */);Expand description
System Control Register
Implementations
Sourceimpl Ctrl
impl Ctrl
pub const RESET_OFFSET: usize = 0usize
pub const RESET_WIDTH: usize = 1usize
pub const RESET_MASK: u32 = 1u32
pub const RELUCTANCE_OFFSET: usize = 1usize
pub const RELUCTANCE_WIDTH: usize = 8usize
pub const RELUCTANCE_MASK: u32 = 255u32
pub const RELUCTANCE_SIGNED: bool = true
pub const RELUCTANCE_INTWIDTH: isize = 1isize
pub const RELUCTANCE_FRACWIDTH: isize = 7isize
pub const DIRACTANCE_OFFSET: usize = 9usize
pub const DIRACTANCE_WIDTH: usize = 8usize
pub const DIRACTANCE_MASK: u32 = 255u32
Sourcepub fn reluctance(&self) -> ReluctanceFixedPoint
pub fn reluctance(&self) -> ReluctanceFixedPoint
Magneto-reluctance
Set the absolute magneto-reluctance.
Sourcepub fn set_reluctance(&mut self, val: ReluctanceFixedPoint)
pub fn set_reluctance(&mut self, val: ReluctanceFixedPoint)
Magneto-reluctance
Set the absolute magneto-reluctance.
Sourcepub fn diractance(&self) -> u8
pub fn diractance(&self) -> u8
Capactive diractance
Capacitive diractance relative to the lunar waneshaft.
The amount of energy that can be stored in a capacitor is E = 1/2 CV^2, but that is irrelevant because nobody knows what ‘diractance’ is, so we’ll leave that as an exercise to the reader.
Sourcepub fn set_diractance(&mut self, val: u8)
pub fn set_diractance(&mut self, val: u8)
Capactive diractance
Capacitive diractance relative to the lunar waneshaft.
The amount of energy that can be stored in a capacitor is E = 1/2 CV^2, but that is irrelevant because nobody knows what ‘diractance’ is, so we’ll leave that as an exercise to the reader.